@@ -15,7 +15,13 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
-from .literals import ChannelState, Mode, OriginManifestType, RelativePosition, TypeType
+from .literals import (
+    ChannelStateType,
+    ModeType,
+    OriginManifestTypeType,
+    RelativePositionType,
+    TypeType,
+)
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -108,7 +114,7 @@ AdMarkerPassthroughTypeDef = TypedDict(
 AvailSuppressionTypeDef = TypedDict(
     "AvailSuppressionTypeDef",
     {
-        "Mode": Mode,
+        "Mode": ModeType,
         "Value": str,
     },
     total=False,
@@ -162,7 +168,7 @@ CreateChannelResponseTypeDef = TypedDict(
     {
         "Arn": str,
         "ChannelName": str,
-        "ChannelState": ChannelState,
+        "ChannelState": ChannelStateType,
         "CreationTime": datetime,
         "LastModifiedTime": datetime,
         "Outputs": List["ResponseOutputItemTypeDef"],
@@ -219,7 +225,7 @@ DashConfigurationForPutTypeDef = TypedDict(
     "DashConfigurationForPutTypeDef",
     {
         "MpdLocation": str,
-        "OriginManifestType": OriginManifestType,
+        "OriginManifestType": OriginManifestTypeType,
     },
     total=False,
 )
@@ -229,7 +235,7 @@ DashConfigurationTypeDef = TypedDict(
     {
         "ManifestEndpointPrefix": str,
         "MpdLocation": str,
-        "OriginManifestType": OriginManifestType,
+        "OriginManifestType": OriginManifestTypeType,
     },
     total=False,
 )
@@ -258,7 +264,7 @@ DescribeChannelResponseTypeDef = TypedDict(
     {
         "Arn": str,
         "ChannelName": str,
-        "ChannelState": ChannelState,
+        "ChannelState": ChannelStateType,
         "CreationTime": datetime,
         "LastModifiedTime": datetime,
         "Outputs": List["ResponseOutputItemTypeDef"],
@@ -632,7 +638,7 @@ SpliceInsertMessageTypeDef = TypedDict(
 _RequiredTransitionTypeDef = TypedDict(
     "_RequiredTransitionTypeDef",
     {
-        "RelativePosition": RelativePosition,
+        "RelativePosition": RelativePositionType,
         "Type": str,
     },
 )
@@ -654,7 +660,7 @@ UpdateChannelResponseTypeDef = TypedDict(
     {
         "Arn": str,
         "ChannelName": str,
-        "ChannelState": ChannelState,
+        "ChannelState": ChannelStateType,
         "CreationTime": datetime,
         "LastModifiedTime": datetime,
         "Outputs": List["ResponseOutputItemTypeDef"],
